# Meta Model v3
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/meta-model-v3#overview)
  * [SAP LeanIX Meta Model v3](https://help.sap.com/docs/leanix/ea/meta-model-v3#sap-leanix-meta-model-v3)
  * [Optional Extensions of the Data Model](https://help.sap.com/docs/leanix/ea/meta-model-v3#optional-extensions-of-the-data-model)
  * [Modeling Guidelines for Meta Model v3](https://help.sap.com/docs/leanix/ea/meta-model-v3#modeling-guidelines-for-meta-model-v3)
